Trove Library Specific Commandments
-------------------------------------

- [T101] Validate that LOG messages, except debug ones, are translated
- [T102] Validate that debug level logs are not translated
- [T103] Exception messages should be translated

